package com.steering.mes.fprecall;

import java.io.Serializable;

public class FPPlan implements Serializable{
    private String llDept;
    private String pLKind;
    private String pSteelGrade;
    private String pSteelLevel;
    private String pDM;
    private String pLGPUnit;
    private String sLGPWeight;
    private String tARGET;
    private String gPZ;
    private String gSteelGrade;
    private String gSteelLevel;
    private String wAIJING;
    private String bIHOU;
    private String gkx;
    private String gPLode;
    private String jZNY;
    private String cPUnit;
    public String getcPUnit() {
		return cPUnit;
	}
	public void setcPUnit(String cPUnit) {
		this.cPUnit = cPUnit;
	}
	public String getcPWeight() {
		return cPWeight;
	}
	public void setcPWeight(String cPWeight) {
		this.cPWeight = cPWeight;
	}
	private String cPWeight;
    public String getjZNY() {
		return jZNY;
	}
	public void setjZNY(String jZNY) {
		this.jZNY = jZNY;
	}
	public String getgPLode() {
		return gPLode;
	}
	public void setgPLode(String gPLode) {
		this.gPLode = gPLode;
	}
	public String getzGLode() {
		return zGLode;
	}
	public void setzGLode(String zGLode) {
		this.zGLode = zGLode;
	}
	private String zGLode;
	public String getLlDept() {
		return llDept;
	}
	public void setLlDept(String llDept) {
		this.llDept = llDept;
	}
	public String getpLKind() {
		return pLKind;
	}
	public void setpLKind(String pLKind) {
		this.pLKind = pLKind;
	}
	public String getpSteelGrade() {
		return pSteelGrade;
	}
	public void setpSteelGrade(String pSteelGrade) {
		this.pSteelGrade = pSteelGrade;
	}
	public String getpSteelLevel() {
		return pSteelLevel;
	}
	public void setpSteelLevel(String pSteelLevel) {
		this.pSteelLevel = pSteelLevel;
	}
	public String getpDM() {
		return pDM;
	}
	public void setpDM(String pDM) {
		this.pDM = pDM;
	}
	public String getpLGPUnit() {
		return pLGPUnit;
	}
	public void setpLGPUnit(String pLGPUnit) {
		this.pLGPUnit = pLGPUnit;
	}
	public String getsLGPWeight() {
		return sLGPWeight;
	}
	public void setsLGPWeight(String sLGPWeight) {
		this.sLGPWeight = sLGPWeight;
	}
	public String gettARGET() {
		return tARGET;
	}
	public void settARGET(String tARGET) {
		this.tARGET = tARGET;
	}
	public String getgPZ() {
		return gPZ;
	}
	public void setgPZ(String gPZ) {
		this.gPZ = gPZ;
	}
	public String getgSteelGrade() {
		return gSteelGrade;
	}
	public void setgSteelGrade(String gSteelGrade) {
		this.gSteelGrade = gSteelGrade;
	}
	public String getgSteelLevel() {
		return gSteelLevel;
	}
	public void setgSteelLevel(String gSteelLevel) {
		this.gSteelLevel = gSteelLevel;
	}
	public String getwAIJING() {
		return wAIJING;
	}
	public void setwAIJING(String wAIJING) {
		this.wAIJING = wAIJING;
	}
	public String getbIHOU() {
		return bIHOU;
	}
	public void setbIHOU(String bIHOU) {
		this.bIHOU = bIHOU;
	}
	public String getGkx() {
		return gkx;
	}
	public void setGkx(String gkx) {
		this.gkx = gkx;
	}
	
}