package com.steering.mes.fprecall;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import CoreFS.SA06.CoreReturnObject;
import CoreFS.SA08.CoreXmlSqlParsersFactory;

import com.steering.comm.db.DBCommon;

public class corefprecall extends DBCommon {
//	TZH 24.4.24 注销物流接口
//	public CoreReturnObject getLineList(String name) {
//		// String deletedFlag = includeDeleted ? "0" : "";
//		Object[] params = new Object[] {name};
//		// return this.getDataBySqlID("corefprecall.QUERY");
//		return this.getDataBySqlID("MSSQL1Dao", "corefprecall.QUERY", params);
//	}
//	public CoreReturnObject getLineList_all() {
//		
//		return this.getDataBySqlID("MSSQL1Dao", "corefprecall.QUERY_ALL");
//	}
//    public CoreReturnObject getFPJY() {
//		
//		return this.getDataBySqlID("MSSQL1Dao", "corefprecall.QUERY_FPJY");
//	}
//
//	public CoreReturnObject getGXType() {
//		return this.getDataBySqlID("MSSQL1Dao", "corefprecall.GXType");
//	}
//	public CoreReturnObject getLeiXing() {
//		return this.getDataBySqlID("MSSQL1Dao", "corefprecall.LeiXing");
//	}
//	public CoreReturnObject getGX() {
//		return this.getDataBySqlID("MSSQL1Dao", "corefprecall.GX");
//	}

	public CoreReturnObject update(ArrayList<String> list,
			ArrayList<String> list2, ArrayList<String> list3){
		CoreReturnObject cro = new CoreReturnObject();
		try{
			ArrayList<String> sqllist = new ArrayList<String>();
			ArrayList<Object[]> params = new ArrayList<Object[]>();
			sqllist.add(CoreXmlSqlParsersFactory.getSql("corefprecall.WriteJY"));
			params.add(list.toArray());
			String sql = CoreXmlSqlParsersFactory.getSql("corefprecall.StoreCount");
//			TZH 24.4.24 注销物流接口
//			Connection con = this.getDao("MSSQL1Dao").getConnection();
//			PreparedStatement ps = con.prepareStatement(sql);
//			ps.setObject(1, list.get(0));
//			ResultSet rs = ps.executeQuery();
			int count = 0;
//			if(rs.next()){
//				count = rs.getInt("COUNT");
//			}
			if(count == 0){
				sqllist.add(CoreXmlSqlParsersFactory.getSql("corefprecall.WriteStore"));
				params.add(list2.toArray());
			}else{
				String str = list3.get(0);
				Object[] params3 = new Object[]{list3.get(1),list3.get(2),list3.get(3)};
				if(str == "穿孔前")
				{
					sqllist.add(CoreXmlSqlParsersFactory.getSql("corefprecall.UpdateStoreP"));
				}
				else
				{
					sqllist.add(CoreXmlSqlParsersFactory.getSql("corefprecall.UpdateStoreG"));
				}
				params.add(params3);
			}
//			TZH 24.4.24 注销物流接口
//			cro = this.setData("MSSQL1Dao", sqllist, params);
		}catch(Exception ex){
			cro.setV_errCode(-1);
			cro.setV_errMsg(ex.getMessage());
		}
		
		return cro;
	}
	
//	TZH 24.4.24 注销物流接口
//	public CoreReturnObject tb(ArrayList<FPPlan> plans) {
//		ArrayList sqllist = new ArrayList();
//		for(int i = 0;i < plans.size();i++){
//			FPPlan plan = plans.get(i);
//	
//			String sql = "INSERT INTO [TPCO_ZGTJ].[dbo].[Tab_JZ_finance]";
//			       sql+= "([LLDept],[PLKind],[PSteelGrade],[PSteelLevel],[PDM],[SLGPUnit],[SLGPWeight],[TARGET]";
//			       sql+= ",[GPZ],[GSteelGrade],[GSteelLevel],[WAIJING],[BIHOU],[Gkx],[CPUnit],[CPWeight]";
//			       sql+=",[GPLode],[ZGLode],[JZNY])";
//			       sql+=" VALUES('";
//			       sql+=plan.getLlDept()+"','"+plan.getpLKind()+"','"+plan.getpSteelGrade()+"','"+plan.getpSteelLevel()+"','";
//			       sql+=plan.getpDM()+"','"+plan.getpLGPUnit()+"','"+plan.getsLGPWeight()+"','"+plan.gettARGET()+"','";
//			       sql+=plan.getgPZ()+"','"+plan.getgSteelGrade()+"','"+plan.getgSteelLevel()+"','"+plan.getwAIJING()+"','";
//			       sql+=plan.getbIHOU()+"','"+plan.getGkx()+"','"+plan.getcPUnit()+"','"+plan.getcPWeight()+"','";
//			       sql+=plan.getgPLode()+"','"+plan.getzGLode()+"','"+plan.getjZNY()+"')";
//			String sqlforupdate = "update [TPCO_ZGTJ].[dbo].Tab_HBStore set Status = '30' where rtrim(ltrim(SLcode))+rtrim(ltrim(ZGcode)) in(";
//			sqlforupdate += "'"+plan.getgPLode()+plan.getzGLode()+"'";
//			if(i < plans.size()-1){
//				sqlforupdate += ",";
//			}
//			sqlforupdate += ")";
//		    sqllist.add(sql);    
//		    sqllist.add(sqlforupdate);   
//		}
//		return this.setData("MSSQL1Dao", sqllist, null);
//	}
}
